@@ -21,7 +21,6 @@ typedef struct _auth_basic_queue_node auth_basic_queue_node;
 /* queue of auth requests waiting for verification to occur */
 struct _auth_basic_queue_node {
     auth_basic_queue_node *next;
-    auth_user_request_t *auth_user_request;
     RH *handler;
     void *data;
 };
@@ -42,6 +41,8 @@ struct _auth_basic_config {
     char *basicAuthRealm;
     wordlist *authenticate;
     time_t credentialsTTL;
+    int casesensitive;
+    int blankpassword;
 };
 
 typedef struct _auth_basic_config auth_basic_config;
